.. BigJob documentation master file, created by
   sphinx-quickstart on Mon Dec  3 21:55:42 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

BigJob |version| Documentation
==============================

Contents:

.. toctree::
   :numbered:
   :maxdepth: 2

   intro/index.rst    
   install/index.rst
   usage/index.rst
   patterns/index.rst
   library/index.rst
   tutorial/index.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

